[protozero] 01/04: Imported Upstream version 1.4.2

Bas Couwenberg sebastic at debian.org
Sat Aug 27 08:19:30 UTC 2016


This is an automated email from the git hooks/post-receive script.

sebastic pushed a commit to branch master
in repository protozero.

commit 09609b21ef0399b6d5501f9b4f2f4f6e9cea749f
Author: Bas Couwenberg <sebastic at xs4all.nl>
Date:   Sat Aug 27 09:56:28 2016 +0200

    Imported Upstream version 1.4.2
---
 CHANGELOG.md                    | 16 +++++++++++++---
 CONTRIBUTING.md                 |  6 +++++-
 Makefile                        |  2 +-
 include/protozero/iterators.hpp | 10 +++++-----
 include/protozero/version.hpp   |  4 ++--
 package.json                    |  2 +-
 6 files changed, 27 insertions(+), 13 deletions(-)

diff --git a/CHANGELOG.md b/CHANGELOG.md
index 34037bd..2a7dd14 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -13,15 +13,23 @@ This project adheres to [Semantic Versioning](http://semver.org/).
 ### Fixed
 
 
+## [1.4.2] - 2016-08-27
+
+### Fixed
+
+- Compile fix: Variable shadowing.
+
+
 ## [1.4.1] - 2016-08-21
 
 ### Fixed
 
- - GCC 4.8 compile fixed
+- GCC 4.8 compile fixed
 
 ### Added
 
-- New ability to dynamically require the module as a node module to ease building against from other node C++ modules.
+- New ability to dynamically require the module as a node module to ease
+  building against from other node C++ modules.
 
 ## [1.4.0] - 2016-07-22
 
@@ -100,7 +108,9 @@ This project adheres to [Semantic Versioning](http://semver.org/).
 - Make pbf reader and writer code endianess-aware.
 
 
-[unreleased]: https://github.com/osmcode/libosmium/compare/v1.4.0...HEAD
+[unreleased]: https://github.com/osmcode/libosmium/compare/v1.4.2...HEAD
+[1.4.2]: https://github.com/osmcode/libosmium/compare/v1.4.1...v1.4.2
+[1.4.1]: https://github.com/osmcode/libosmium/compare/v1.4.0...v1.4.1
 [1.4.0]: https://github.com/osmcode/libosmium/compare/v1.3.0...v1.4.0
 [1.3.0]: https://github.com/osmcode/libosmium/compare/v1.2.3...v1.3.0
 [1.2.3]: https://github.com/osmcode/libosmium/compare/v1.2.2...v1.2.3
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index b662b25..8528cdd 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -6,11 +6,15 @@ To release a new protozero version:
 
  - Make sure all tests are passing on travis and appveyor
  - Update version number in
-   - include/protozero/version.hpp
+   - include/protozero/version.hpp (two places)
    - package.json
  - Update CHANGELOG.md
+   (don't forget links at the bottom of the file)
  - Update UPGRADING.md
  - Create a new tag and push to github `git push --tags`
+ - Go to https://github.com/mapbox/protozero/releases
+   and edit the new release. Put "Version x.y.z" in title and
+   cut-and-paste entry from CHANGELOG.md.
  - Publish to npm:
    - First run `make testpack` to see what files will be published
    - If you see any unwanted files, then add them to `.npmignore`
diff --git a/Makefile b/Makefile
index 5c72235..ec28029 100644
--- a/Makefile
+++ b/Makefile
@@ -6,7 +6,7 @@ LDFLAGS := $(LDFLAGS)
 # Installation directory
 DESTDIR ?= /usr
 
-WARNING_FLAGS := -Wall -Wextra -pedantic -Wsign-compare -Wsign-conversion -Wunused-parameter -Wno-float-equal -Wno-covered-switch-default
+WARNING_FLAGS := -Wall -Wextra -pedantic -Wsign-compare -Wsign-conversion -Wunused-parameter -Wno-float-equal -Wno-covered-switch-default -Wshadow
 
 ifneq ($(findstring clang,$(CXX)),)
     WARNING_FLAGS += -Wno-reserved-id-macro -Weverything -Wno-weak-vtables -Wno-c++98-compat -Wno-c++98-compat-pedantic -Wno-exit-time-destructors -Wno-switch-enum -Wno-padded -Wno-documentation-unknown-command
diff --git a/include/protozero/version.hpp b/include/protozero/version.hpp
index 975aad8..127e649 100644
--- a/include/protozero/version.hpp
+++ b/include/protozero/version.hpp
@@ -23,13 +23,13 @@ documentation.
 #define PROTOZERO_VERSION_MINOR 4
 
 /// The patch number
-#define PROTOZERO_VERSION_PATCH 1
+#define PROTOZERO_VERSION_PATCH 2
 
 /// The complete version number
 #define PROTOZERO_VERSION_CODE (PROTOZERO_VERSION_MAJOR * 10000 + PROTOZERO_VERSION_MINOR * 100 + PROTOZERO_VERSION_PATCH)
 
 /// Version number as string
-#define PROTOZERO_VERSION_STRING "1.4.0"
+#define PROTOZERO_VERSION_STRING "1.4.2"
 
 
 #endif // PROTOZERO_VERSION_HPP
diff --git a/package.json b/package.json
index 1eca15a..8598938 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
 {
     "name": "protozero",
-    "version": "1.4.1",
+    "version": "1.4.2",
     "description": "Minimalist protocol buffer decoder and encoder in C++",
     "main": "include_dirs.js",
     "repository"   :  {

diff --git a/include/protozero/iterators.hpp b/include/protozero/iterators.hpp
index 813d96b..00ba919 100644
--- a/include/protozero/iterators.hpp
+++ b/include/protozero/iterators.hpp
@@ -76,12 +76,12 @@ public:
     /**
      * Create iterator range from two iterators.
      *
      * @param first Iterator to beginning or range.
      * @param last Iterator to end or range.
      */
-    constexpr iterator_range(iterator&& first, iterator&& last) :
-        P(std::forward<iterator>(first),
-          std::forward<iterator>(last)) {
+    constexpr iterator_range(iterator&& first_iterator, iterator&& last_iterator) :
+        P(std::forward<iterator>(first_iterator),
+          std::forward<iterator>(last_iterator)) {
     }
 
     /// Return iterator to beginning of range.
@@ -76,12 +76,12 @@ public:
      * Create iterator range from two iterators.
      *
-     * @param first Iterator to beginning or range.
-     * @param last Iterator to end or range.
+     * @param first_iterator Iterator to beginning or range.
+     * @param last_iterator Iterator to end or range.
      */
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-grass/protozero.git



More information about the Pkg-grass-devel mailing list